en_zh = {
    "Politics": "政治",
    "Heresy": "邪教",
    "Terrorism": "恐怖主义",
    "Crime": "犯罪",
    "Porn": "色情",
    "Gamble": "赌博",
    "Contraband": "违禁品",
    "SensitiveEvent": "敏感事件",
    "Abuse": "辱骂",
    "IllegalWebsite": "违规网站",
    "Adv": "广告",
    "Normal": "健康",
    "OtherViolations": "其他违规",
}

id2level = {
    0: 'Pass',
    1: 'Review',
    2: 'Reject'
}

id2label = {
    100: '色情',
    200: '广告',
    300: '暴恐',
    400: '违禁品',  # 原 违禁
    500: '政治',
    600: '辱骂',  # 原 谩骂
    700: '灌水',
    900: '其他'
}
